@@ -206,13 +206,22 @@ namespace Rstats {
       Rstats::Vector* v1 = Rstats::VectorFunc::new_double(length);
       for (IV i = 0; i < length; i++) {
         SV* sv_value = Rstats::pl_av_fetch(sv_values, i);
-        
+
         if (SvOK(sv_value)) {
-          Rstats::VectorFunc::set_double_value(
-            v1,
-            i,
-            SvNV(sv_value)
-          );
+          char* sv_value_str = SvPV_nolen(sv_value);
+          if (strEQ(sv_value_str, "NaN")) {
+            Rstats::VectorFunc::set_double_value(v1, i, NAN);
+          }
+          else if (strEQ(sv_value_str, "Inf")) {
+            Rstats::VectorFunc::set_double_value(v1, i, INFINITY);
+          }
+          else if (strEQ(sv_value_str, "-Inf")) {
+            Rstats::VectorFunc::set_double_value(v1, i, -(INFINITY));
+          }
+          else {
+            NV value = SvNV(sv_value);
+            Rstats::VectorFunc::set_double_value(v1, i, value);
+          }
         }
         else {
           Rstats::VectorFunc::add_na_position(v1, i);
@@ -242,8 +251,47 @@ namespace Rstats {
         if (SvOK(sv_value)) {
           SV* sv_value_re = Rstats::pl_hv_fetch(sv_value, "re");
           SV* sv_value_im = Rstats::pl_hv_fetch(sv_value, "im");
-          NV re = SvNV(sv_value_re);
-          NV im = SvNV(sv_value_im);
+
+          NV re;
+          if (SvOK(sv_value_re)) {
+            char* sv_value_re_str = SvPV_nolen(sv_value_re);
+            if (strEQ(sv_value_re_str, "NaN")) {
+              re = NAN;
+            }
+            else if (strEQ(sv_value_re_str, "Inf")) {
+              re = INFINITY;
+            }
+            else if (strEQ(sv_value_re_str, "-Inf")) {
+              re = -(INFINITY);
+            }
+            else {
+              re = SvNV(sv_value_re);
+            }
+          }
+          else {
+            re = 0;
+          }
+          
+
+          NV im;
+          if (SvOK(sv_value_im)) {
+            char* sv_value_im_str = SvPV_nolen(sv_value_im);
+            if (strEQ(sv_value_im_str, "NaN")) {
+              im = NAN;
+            }
+            else if (strEQ(sv_value_im_str, "Inf")) {
+              im = INFINITY;
+            }
+            else if (strEQ(sv_value_im_str, "-Inf")) {
+              im = -(INFINITY);
+            }
+            else {
+              im = SvNV(sv_value_im);
+            }
+          }
+          else {
+            im = 0;
+          }
           
           Rstats::VectorFunc::set_complex_value(
             v1,
