@@ -19,32 +19,11 @@ sub monkey_patch {
   *{"${class}::$_"} = $NAME->("${class}::$_", $patch{$_}) for keys %patch;
 }
 
-my $type_level = {
-  character => 6,
-  complex => 5,
-  double => 4,
-  integer => 3,
-  logical => 2,
-  na => 1
-};
-
-sub higher_type {
-  my $r = shift;
-  
-  my ($type1, $type2) = @_;
-  
-  if ($type_level->{$type1} > $type_level->{$type2}) {
-    return $type1;
-  }
-  else {
-    return $type2;
-  }
-}
-
 sub parse_index {
   my $r = shift;
   
-  my ($x1, $drop, @_indexs) = @_;
+  my ($x1, $drop, $_indexs) = @_;
+  my @_indexs = @$_indexs;
   
   my $x1_dim = $x1->dim_as_array->values;
   my @indexs;
@@ -61,7 +40,7 @@ sub parse_index {
       push @$poss, $i;
     }
     
-    return ($poss, []);
+    return [$poss, []];
   }
   else {
     for (my $i = 0; $i < @$x1_dim; $i++) {
@@ -131,7 +110,7 @@ sub parse_index {
 
       push @indexs, $index;
 
-      my $count = $index->vector->length_value;
+      my $count = Rstats::VectorFunc::length_value($index->vector);
       push @x2_dim, $count unless $count == 1 && $drop;
     }
     @x2_dim = (1) unless @x2_dim;
@@ -140,7 +119,7 @@ sub parse_index {
     my $ords = cross_product($index_values);
     my @poss = map { Rstats::Util::index_to_pos($_, $x1_dim) } @$ords;
   
-    return (\@poss, \@x2_dim, \@indexs);
+    return [\@poss, \@x2_dim, \@indexs];
   }
 }
 
